@@ -1,23 +1,24 @@
 """This module contains functions for directly interacting with memuc.exe."""
 from contextlib import suppress
 from os.path import join, normpath
-from subprocess import (
-    PIPE,
-    STARTF_USESHOWWINDOW,
-    STARTUPINFO,
-    SW_HIDE,
-    CalledProcessError,
-    Popen,
-    TimeoutExpired,
-)
+from subprocess import PIPE, CalledProcessError, Popen, TimeoutExpired
 from tempfile import NamedTemporaryFile
 
-from ._constants import DEBUG, WINREG_EN
+from ._constants import WIN32, WINREG_EN
 from .exceptions import PyMemucError, PyMemucTimeoutExpired
 
 if WINREG_EN:
     from winreg import HKEY_LOCAL_MACHINE, ConnectRegistry, OpenKey, QueryValueEx
 
+if WIN32:
+    from subprocess import STARTF_USESHOWWINDOW, STARTUPINFO, SW_HIDE
+
+    ST_INFO = STARTUPINFO()
+    ST_INFO.dwFlags = STARTF_USESHOWWINDOW
+    ST_INFO.wShowWindow = SW_HIDE
+else:
+    ST_INFO = None
+
 
 @staticmethod
 def _get_memu_top_level() -> str:
@@ -55,6 +56,7 @@ def memuc_run(
     :return: the return code and the output of the command
     :rtype: tuple[int, str]
     :raises PyMemucError: an error if the command failed
+    :raises PyMemucTimeoutExpired: an error if the command timed out
     """
     # sourcery skip: extract-method
     args.insert(0, self.memuc_path)
@@ -63,9 +65,6 @@ def memuc_run(
     if timeout is None:
         args += "-t" if non_blocking else ""
     try:
-        startupinfo = STARTUPINFO()
-        startupinfo.dwFlags = STARTF_USESHOWWINDOW
-        startupinfo.wShowWindow = SW_HIDE
         with NamedTemporaryFile(mode="r+", delete=False) as stdout_file:
             with Popen(
                 args,
@@ -73,13 +72,13 @@ def memuc_run(
                 stdout=stdout_file,
                 stderr=PIPE,
                 shell=False,
-                startupinfo=startupinfo,
+                startupinfo=ST_INFO,
             ) as process:
                 return_code = process.wait(timeout)
                 stdout_file.flush()
                 stdout_file.seek(0)
                 result = stdout_file.read()
-                if DEBUG:
+                if self.debug:
                     print("pymemuc._memuc.memuc_run:")
                     print(f"\tCommand: {' '.join(args)}")
                     print(f"\tOutput [{return_code}]: {result}")
@@ -91,7 +90,7 @@ def memuc_run(
 
 
 # TODO: add output parsing
-def check_task_status(self, task_id):
+def check_task_status(self, task_id: str) -> tuple[int, str]:
     """Check the status of a task
 
     :param task_id: Asynchronous task ID
@@ -99,4 +98,4 @@ def check_task_status(self, task_id):
     :return: the return code and the output of the command.
     :rtype: tuple[int, str]
     """
-    return self.memuc_run(["taskstatus"], task_id)
+    return self.memuc_run(["taskstatus", task_id])
